@@ -2,13 +2,12 @@ package GFgtk;
    use strict;
    use warnings;
    
-   our $VERSION = '0.081';
+   our $VERSION = '0.09';
    
    use Glib ':constants';   # load Glib and import useful constants
    use Gtk3 '-init';        # load Gtk3 module and initialize it
-  # use parent qw(Gtk3::Window);
    use Exporter 'import';   
-   our @EXPORT_OK      = qw<addWidget addVar setScale MainLoop $frame $winScale $winWidth $winHeight $winTitle>;
+   our @EXPORT      = qw<addWidget addVar setScale MainLoop $frame $winScale $winWidth $winHeight $winTitle>;
    our $frame;
    
    our $winX=30;
@@ -91,7 +90,7 @@ package GFgtk;
 		my ($self,$canvas, $id, $text, $location)=@_;
 		$canvas->{"stattext$id"}=Gtk3::Label->new();
 	    $canvas->{"stattext$id"}->set_label($text);
-	    #$canvas->{"stattext$id"}->set_attributes ();#find out how to set fonts
+	    $canvas->{"stattext$id"}->set_markup('<span size="xx-large" >'.$text.'</span>');
 	    $canvas->put($canvas->{"stattext$id"},${$location}[0] ,${$location}[1]);
         }
         sub aCB{  #adapted from http://www.perlmonks.org/?node_id=799673
@@ -144,12 +143,12 @@ package GFgtk;
 			 my ($self,$canvas, $id, $panelType, $content, $location, $size)=@_;
 			
 			if ($panelType eq "I"){  # Image panels start with I
+				$canvas->{"Image".$id} = Gtk3::Image->new();
+				$canvas->put($canvas->{"Image".$id},${$location}[0] ,${$location}[1]);
 				if (! -e $content){ return; }
 				my $pixbuf = Gtk3::Gdk::Pixbuf->new_from_file($content);
 				my $scaled = $pixbuf->scale_simple(${$size}[0],${$size}[1], 'GDK_INTERP_HYPER');
-				$canvas->{"Image".$id} = Gtk3::Image->new();
 				$canvas->{"Image".$id}->set_from_pixbuf($scaled);
-				$canvas->put($canvas->{"Image".$id},${$location}[0] ,${$location}[1]);					
 			 }
 			if ($panelType eq "T"){  
 				$canvas->{"sw$id"}= Gtk3::ScrolledWindow->new();
@@ -233,7 +232,7 @@ package GFgtk;
 	       if (! -e $file){ print "$file not found\n"; return; }
 				my $pixbuf = Gtk3::Gdk::Pixbuf->new_from_file($file);
 				my $scaled = $pixbuf->scale_simple(${$size}[0],${$size}[1], 'GDK_INTERP_HYPER');
-				$canvas->{"$id"} ->clear;
+				$canvas->{"$id"} ->clear; 
 				$canvas->{"$id"}->set_from_pixbuf($scaled);
 			 }
 		  else {print "Panel not found"}
@@ -324,7 +323,7 @@ package GFgtk;
 # Quit
    sub quit{
 	   my ($self) = @_;
-	   $self ->Close(1);
+	   $self->{window}->destroy();
    }
 1;
 
