@@ -2,7 +2,7 @@ package GFqt;
    use strict;
    use warnings;
    
-   our $VERSION = '0.081';
+   our $VERSION = '0.09';
 
 use QtCore4;
 use QtGui4;
@@ -12,7 +12,7 @@ use QtCore4::slots
 
    
    use Exporter 'import';   
-   our @EXPORT_OK      = qw<addWidget addVar setScale getFrame $frame $winScale $winWidth $winHeight $winTitle>;
+   our @EXPORT   = qw<addWidget addVar setScale getFrame $frame $winScale $winWidth $winHeight $winTitle>;
    our $frame;
    our $app;
    
@@ -59,7 +59,8 @@ use QtCore4::slots
   }
 
 sub mapAction{
-	my $widgetIndex=getItem(shift);
+	my $item=shift;
+	my $widgetIndex=getItem($item);
 	my @widget=@{$widgets[$widgetIndex]};
 	my $wType=shift @widget;
 	if ($widgetIndex !=-1){
@@ -84,6 +85,7 @@ sub mapAction{
 		   elsif ($wtype eq "sp")           {aSP($self, $canvas, @params);}
 		   elsif ($wtype eq "mb")           {$currentMenu=aMB($self,$canvas,$currentMenu,@params) }	       
 	   }
+	    if (defined $currentMenu){ $self->menuBar()->addMenu($self->{$currentMenu}) }
 
 	   sub aBt{
 		   my ($self,$canvas, $id, $label, $location, $size, $action)=@_;
@@ -107,7 +109,7 @@ sub mapAction{
 		   $canvas->{"stattext$id"}->setGeometry(${$location}[0],${$location}[1],32*length $text,24);
         }
        sub aCB{  
-		   my ($self,$canvas, $id, $label, $location)=@_;
+		   my ($self,$canvas, $id, $label, $location,$size,$action)=@_;
 		   $canvas->{"combo$id"}=Qt::ComboBox;
 		   if (defined $oVars{$label}){
 	         my @strings2 = split(",",$oVars{$label});
@@ -115,7 +117,7 @@ sub mapAction{
 				 $canvas->{"combo$id"}->addItem($_);
 			 }
 			 $canvas->{"combo$id"}->setParent($canvas);
-		     $canvas->{"combo$id"}->setGeometry(${$location}[0],${$location}[1], 80,32);
+		     $canvas->{"combo$id"}->setGeometry(${$location}[0],${$location}[1],${$size}[0],${$size}[1]);
 		     $self->connect($canvas->{"combo".$id}, SIGNAL 'currentIndexChanged(int)', $self->{SigMan}, SLOT 'map()');
 		     $self->{SigMan}->setMapping($canvas->{"combo".$id}, "combo".$id);
 
@@ -124,14 +126,15 @@ sub mapAction{
 
 		}
 		 
-        sub aMB{
+      sub aMB{
 	     my ($self,$canvas,$currentMenu, $id, $label, $type, $action)=@_;
 	     if (($lastMenuLabel) &&($label eq $lastMenuLabel)){return $currentMenu} # bug workaround 
 	     else {$lastMenuLabel=$label};	                                         # in menu generator
 	       if ($type eq "menuhead"){
+			   if (defined $currentMenu){ $self->menuBar()->addMenu($self->{$currentMenu}) }
 			   $currentMenu="menu".$id;
 			   $self->{$currentMenu} = Qt::Menu($self->tr($label),$self);
-			   $self->menuBar()->addMenu($self->{$currentMenu})
+			   
 			  # push (@menus, $currentMenu)
 		   }
 		   elsif ($type eq "radio"){
@@ -142,6 +145,7 @@ sub mapAction{
 			   $canvas->{$currentMenu}->addSeparator();
 		   }
 		   else{
+			   #print "MenuItem $label \n";
 			   $self->{"menu".$id."Act"}=Qt::Action($self->tr($label), $self);
 			   $self->connect($self->{"menu".$id."Act"}, SIGNAL 'triggered()', $self->{SigMan}, SLOT 'map()');
 			   $self->{SigMan}->setMapping($self->{"menu".$id."Act"}, "menu".$id);
@@ -155,12 +159,13 @@ sub mapAction{
 			 my ($self,$canvas, $id, $panelType, $content, $location, $size)=@_;
 			
 			if ($panelType eq "I"){  # Image panels start with I
+				    $canvas->{"Image$id"}=Qt::Label();
+				    $canvas->{"Image$id"}->setParent($canvas);
+		            $canvas->{"Image$id"}->setGeometry(${$location}[0],${$location}[1],${$size}[0],${$size}[1]);
 				if (! -e $content){ return; }
-					$canvas->{"Image$id"}=Qt::Label();
 					my $image = Qt::Image(Qt::String($content));
 		            $canvas->{"Image$id"}->setPixmap(Qt::Pixmap::fromImage( $image )->scaled(${$size}[0],${$size}[1]) );
-		            $canvas->{"Image$id"}->setParent($canvas);
-		            $canvas->{"Image$id"}->setGeometry(${$location}[0],${$location}[1],${$size}[0],${$size}[1]);
+		            
 			}
 			if ($panelType eq "T"){ 
 				    $canvas->{"TextCtrl".($id+1)}=Qt::PlainTextEdit;
@@ -234,7 +239,7 @@ sub mapAction{
 	   my ($id,$imageFile)=@_;
 	   my @widget=@{$widgets[getItem($id)]};
 	   my $size= $widget[5];
-	   my $image = Qt::Image(Qt::String($imageFile));
+	   my $image = Qt::Image(Qt::String($imageFile)) or die "could not load Image $!";
 	   $frame->{$id}->setPixmap(Qt::Pixmap::fromImage( $image )->scaled(${$size}[0],${$size}[1]) );
 	   
    }
@@ -308,7 +313,8 @@ sub mapAction{
    
 # Quit
    sub quit{
-	   my ($self) = @_;
-	   $self ->destroy;
+	  $app ->quit();
    }
-1;
+
+
+ 1;
