@@ -2,7 +2,7 @@ package GFtk;
    use strict;
    use warnings;
    
-   our $VERSION = '0.081';
+   our $VERSION = '0.09';
    
    use parent qw(Tk::MainWindow);
    
@@ -12,7 +12,7 @@ package GFtk;
    use MIME::Base64;
    
    use Exporter 'import';   
-   our @EXPORT_OK      = qw<addWidget addVar setScale $frame $winScale $winWidth $winHeight $winTitle>;
+   our @EXPORT  = qw<addWidget addVar setScale $frame $winScale $winWidth $winHeight $winTitle>;
    our $frame;
    
    our $winX=30;
@@ -184,8 +184,6 @@ package GFtk;
 	                         -window => $canvas->{"TextCtrl$id"});
 			 }
 		 }
-        
-	   
    }
 
       
