@@ -3,12 +3,12 @@ package GUIDeFATE;
    use strict;
    use warnings;
    
-   our $VERSION = '0.081';
+   our $VERSION = '0.09';
    
    use Exporter 'import';
    
    our @EXPORT_OK      = qw<$frame>;  # allows manipulation of frame from main.
-   our $target;
+   our $target="";
    our $AppObject;
    our $winX=30;
    our $winY=30;
@@ -20,47 +20,48 @@ package GUIDeFATE;
    my  $log="";
 
 sub new{
-	my ($class,$textGUI,$target,$assist)=@_;
+	(my $class,my $textGUI,$target,my $assist)=@_;
 	if ((!$target)||($target=~/^wx/i)){
 		$target="wx";
-		eval " use GFwx qw<addWidget addVar setScale
-		           \$frame \$winScale \$winWidth \$winHeight \$winTitle>;";
+		eval " use GFwx;";
 		convert($textGUI,$assist);
 		return GFwx->new(); ;
 	}
 	elsif ($target =~m/^gtk/i){
 		$target="gtk";
-		eval " use GFgtk qw<addWidget addVar setScale MainLoop
-		           \$frame \$winScale \$winWidth \$winHeight \$winTitle>;";
+		eval " use GFgtk;";
 		convert($textGUI, $assist);
 		return GFgtk->new(); 
 		
 	}	
 	elsif ($target =~m/^tk/i){
 		$target="tk";
-		eval " use GFtk qw<addWidget addVar setScale 
-		           \$frame \$winScale \$winWidth \$winHeight \$winTitle>;";
+		eval " use GFtk;";
 		convert($textGUI, $assist);
 		return GFtk->new(); 
 	}
 	elsif ($target =~m/^qt/i){
 		$target="qt";
-		eval " use GFqt qw<addWidget addVar setScale
-		           \$frame \$winScale \$winWidth \$winHeight \$winTitle>;";
+		eval " use GFqt;";
+		           
 		convert($textGUI, $assist);
 		my $qtWin=GFqt->new(); 
 		return $qtWin;
 	}
 	elsif ($target =~m/^win32/i){
 		$target="win32";
-		eval " use GFwin32 qw<addWidget addVar setScale 
-		           \$frame \$winScale \$winWidth \$winHeight \$winTitle>;";
+		eval " use GFwin32;";
 		convert($textGUI, $assist);
 		return GFwin32->new(); 
 	}
+	elsif ($target =~m/^html/i){
+		$target="mojo";
+		eval " use GFhtml;";
+		convert($textGUI, $assist);
+		return GFhtml->new(); 
+	}
 }
 
-
 sub convert{
 	my($textGUI,$assist)=@_;
 	my @lines=(split /\n/ ,$textGUI) ;
@@ -182,36 +183,38 @@ sub convert{
 				$log= "Menuhead $1 found\n"; ##
 				if ($verbose){ print $log; }
 				if ($auto){ $autoGen.="#".$log; }
-				addWidget(["mb",$bid++, $1, "menuhead", undef]);
+				addWidget(["mb",$bid, $1, "menuhead", undef]);
+				$bid++;
 				}
 			elsif($line=~/^\-{2}([A-z0-9].*)\;radio/i){
 				$log= "Menu $1  as radio found, calls function &menu$bid \n";##
 				if ($verbose){ print $log; }
 				if ($auto){ $autoGen.="#".$log.makeSub("menu$bid","Menu with label $1"); }
-				addWidget(["mb",$bid, $1, "radio", \&{"main::menu".$bid++}]);
+				addWidget(["mb",$bid, $1, "radio", \&{"main::menu".$bid}]);
 				}
 			elsif($line=~/^\-{2}([A-z0-9].*)\;check/i){
 				$log= "Menu $1 as check found, calls function &menu$bid \n";##
 				if ($verbose){ print $log; }
 				if ($auto){ $autoGen.="#".$log.makeSub("menu$bid","Menu with label $1"); }
-				addWidget(["mb",$bid, $1, "check", \&{"main::menu".$bid++}]);
+				addWidget(["mb",$bid, $1, "check", \&{"main::menu".$bid}]);
 				}
 			elsif($lines[$l]=~/^\-{6}/){
 				$log= "Separator found,\n"; ##
 				if ($verbose){ print $log; }
 				if ($auto){ $autoGen.="#".$log.makeSub("menu$bid","Menu with label $1"); }
-				addWidget(["mb",$bid++, "", "separator",""]);
+				addWidget(["mb",$bid, "", "separator",""]);
 				}
 		    elsif($line=~/^\-{2}([A-z0-9].*)/i){
 				$log= "Menu $1 found, calls function &menu$bid \n";##
 				if ($verbose){ print $log; }
 				if ($auto){ $autoGen.="#".$log.makeSub("menu$bid","Menu with label $1"); }
 				}
-				addWidget(["mb",$bid, $1, "normal", \&{"main::menu".$bid++}]);
+				addWidget(["mb",$bid, $1, "normal", \&{"main::menu".$bid}]);
 				}
 		    elsif($line=~/^\-{3}([A-z0-9].*)/i){
 				$log= "SubMenu $1 found\n";##
 				}
+			$bid++;
 		}
 		
 		if ($auto){
@@ -278,7 +281,10 @@ Perl5.8.8, Exporter, QtCore4, QtGui4 (for Qt interface)
 
 =head1 EXPORTS
 
-$frame
+getFrame()
+returns an object containing Widgets (referencesd by id) and
+GUI interaction functions.  This is actually provided by the middle-man
+((GFwx, GFtk etc)
 
 =head1 DESCRIPTION
 
